@@ -1,12 +1,19 @@
 /*
- * Copyright (C) 2000-2005 SWsoft. All rights reserved.
+ *  Copyright (C) 2000-2006 SWsoft. All rights reserved.
  *
- * This file may be distributed under the terms of the Q Public License
- * as defined by Trolltech AS of Norway and appearing in the file
- * LICENSE.QPL included in the packaging of this file.
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
- * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
- * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include <stdio.h>
@@ -23,21 +30,21 @@
 
 int vps_is_run(vps_handler *h, envid_t veid);
 
-/** Get VPS mount status.
+/** Get VE mount status.
  *
- * @param root		VPS root.
- * @return		1 - VPS mounted
- *			0 - VPS unmounted.
- *			-1- error
+ * @param root		VE root.
+ * @return		 1 - VE mounted
+ *			 0 - VE unmounted.
+ *			-1 - error
  */
 int vps_is_mounted(char *root)
 {
 	return vz_fs_is_mounted(root);
 }
 
-/** Mount VPS.
+/** Mount VE.
  *
- * @param veid		VPS id.
+ * @param veid		VE id.
  * @param fs		file system parameters.
  * @param dq		disk quota parameters.
  * @return		0 on success.
@@ -48,7 +55,7 @@ int fsmount(envid_t veid, fs_param *fs, dq_param *dq)
 
 	/* Create VE_ROOT mount point if not exist */
 	if (make_dir(fs->root, 1)) {
-		logger(0, 0, "Can't create mount point %s", fs->root);
+		logger(-1, 0, "Can't create mount point %s", fs->root);
 		return VZ_FS_MPOINTCREATE;
 	}
 	if ((ret = vps_quotaon(veid, fs->private, dq)))
@@ -78,16 +85,16 @@ static int real_umount(envid_t veid, char *root)
 		sleep(1);
 	}
 	if (ret) {
-		logger(0, errno, "Can't umount: %s", root);
+		logger(-1, errno, "Can't umount: %s", root);
 		ret = VZ_FS_CANTUMOUNT;
 	}
 	return ret;
 }
 
-/** Unmount VPS.
+/** Unmount VE.
  *
- * @param veid		VPS id.
- * @param root		VPS root.
+ * @param veid		VE id.
+ * @param root		VE root.
  * @return		0 on success.
  */
 int fsumount(envid_t veid, char *root)
@@ -101,10 +108,10 @@ int fsumount(envid_t veid, char *root)
 	return ret;
 }
 
-/** Mount VPS and run mount action script if exists.
+/** Mount VE and run mount action script if exists.
  *
- * @param h		VPS handler.
- * @param veid		VPS id.
+ * @param h		VE handler.
+ * @param veid		VE id.
  * @param fs		file system parameters.
  * @param dq		disk quota parameters.
  * @param skip		skip mount action scrips
@@ -121,22 +128,22 @@ int vps_mount(vps_handler *h, envid_t veid, fs_param *fs, dq_param *dq,
 	if (check_var(fs->private, "VE_PRIVATE is not set"))
 		return VZ_VE_PRIVATE_NOTSET;
 	if (!stat_file(fs->private)) {
-		logger(0, 0, "VPS private area %s does not exist", fs->private);
+		logger(-1, 0, "VE private area %s does not exist", fs->private);
 		return VZ_FS_NOPRVT;
 	}
 	if (vps_is_mounted(fs->root)) {
-		logger(0, 0, "VPS is already mounted");
+		logger(-1, 0, "VE is already mounted");
 		return 0;
 	}
 	if ((ret = fsmount(veid, fs, dq)))
 		return ret;
-	/* Execute per VPS & global mount scripts */
+	/* Execute per VE & global mount scripts */
 	if (!(skip & SKIP_ACTION_SCRIPT)) {
 		snprintf(buf, sizeof(buf), "%svps.%s", VPS_CONF_DIR,
 			MOUNT_PREFIX);
 		for (i = 0; i < 2; i++) {
 			if (run_pre_script(veid, buf)) {
-				logger(0, 0, "Error executing mount script %s",
+				logger(-1, 0, "Error executing mount script %s",
 					buf);
 				fsumount(veid, fs->root);
 				return VZ_ACTIONSCRIPT_ERROR;
@@ -145,16 +152,16 @@ int vps_mount(vps_handler *h, envid_t veid, fs_param *fs, dq_param *dq,
 				veid, MOUNT_PREFIX);
         	}
 	}
-	logger(0, 0, "VPS is mounted");
+	logger(0, 0, "VE is mounted");
 
 	return 0;
 }
 
-/** Unmount VPS and run unmount action script if exists.
+/** Unmount VE and run unmount action script if exists.
  *
- * @param h		VPS handler.
- * @param veid		VPS id.
- * @param root		VPS root.
+ * @param h		VE handler.
+ * @param veid		VE id.
+ * @param root		VE root.
  * @param skip		skip unmount action scrips
  * @return		0 on success.
  */
@@ -164,11 +171,11 @@ int vps_umount(vps_handler *h, envid_t veid, char *root, skipFlags skip)
 	int ret, i;
 
 	if (!vps_is_mounted(root)) {
-		logger(0, 0, "VPS is not mounted");
+		logger(-1, 0, "VE is not mounted");
 		return VZ_FS_NOT_MOUNTED;
 	}
 	if (vps_is_run(h, veid)) {
-		logger(0, 0, "VPS is running. Stop VPS first");
+		logger(-1, 0, "VE is running. Stop VE first");
 		return 0;
 	}
 	if (!(skip & SKIP_ACTION_SCRIPT)) {
@@ -176,7 +183,7 @@ int vps_umount(vps_handler *h, envid_t veid, char *root, skipFlags skip)
 			UMOUNT_PREFIX);
 		for (i = 0; i < 2; i++) {
 			if (run_pre_script(veid, buf)) {
-				logger(0, 0, "Error executing umount script %s",
+				logger(-1, 0, "Error executing umount script %s",
 					buf);
 				return VZ_ACTIONSCRIPT_ERROR;
 			}
@@ -185,7 +192,7 @@ int vps_umount(vps_handler *h, envid_t veid, char *root, skipFlags skip)
 		}
 	}
 	if (!(ret = fsumount(veid, root)))
-		logger(0, 0, "VPS is unmounted");
+		logger(0, 0, "VE is unmounted");
 
 	return 0;
 }
@@ -199,7 +206,7 @@ int vps_set_fs(fs_param *g_fs, fs_param *fs)
 	if (check_var(g_fs->private, "VE_PRIVATE is not set"))
 		return VZ_VE_PRIVATE_NOTSET;
 	if (!vps_is_mounted(g_fs->root)) {
-		logger(0, 0, "VPS is not mounted");
+		logger(-1, 0, "VE is not mounted");
 		return VZ_FS_NOT_MOUNTED;
 	}
 	g_fs->noatime = fs->noatime;
