@@ -1,12 +1,19 @@
 /*
- * Copyright (C) 2000-2005 SWsoft. All rights reserved.
+ *  Copyright (C) 2000-2006 SWsoft. All rights reserved.
  *
- * This file may be distributed under the terms of the Q Public License
- * as defined by Trolltech AS of Norway and appearing in the file
- * LICENSE.QPL included in the packaging of this file.
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
- * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
- * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include "stdlib.h"
@@ -17,7 +24,7 @@
 
 char *list2str_c(char *name, char c, list_head_t *head)
 {
-	char *buf = NULL;
+	char *buf = NULL, *tmp;
 	int buf_len, len, r;
 	char *sp, *ep;
 	const int delta = 256;
@@ -54,9 +61,12 @@ char *list2str_c(char *name, char c, list_head_t *head)
 			int cur_len = sp - buf;
 
 			buf_len += delta > len ? delta : len + 1;
-			buf = realloc(buf, buf_len);
-			if (buf == NULL)
+			tmp = realloc(buf, buf_len);
+			if (tmp == NULL) {
+				free(buf);
 				return NULL;
+			}
+			buf = tmp;
 			ep = buf + buf_len;
 			sp = buf + cur_len;
 		}
