@@ -1,12 +1,19 @@
 /*
- * Copyright (C) 2000-2005 SWsoft. All rights reserved.
+ *  Copyright (C) 2000-2006 SWsoft. All rights reserved.
  *
- * This file may be distributed under the terms of the Q Public License
- * as defined by Trolltech AS of Norway and appearing in the file
- * LICENSE.QPL included in the packaging of this file.
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
- * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
- * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include <stdlib.h>
@@ -41,7 +48,7 @@ void logger(int log_level, int err_no, const char *format, ...)
 	FILE *out;
 	char date[64];
 
-	if (!log_level)
+	if (log_level < 0)
 		out = stderr;
 	else
 		out = stdout;
@@ -63,7 +70,7 @@ void logger(int log_level, int err_no, const char *format, ...)
 
 		fprintf(g_log.fp, "%s %s : ", date, g_log.prog);
 		if (g_log.veid)
-			fprintf(g_log.fp, "VPS %d : ", g_log.veid);
+			fprintf(g_log.fp, "VE %d : ", g_log.veid);
 		vfprintf(g_log.fp, format, ap);
 		if (err_no) 
 			fprintf(g_log.fp, ": %s", strerror(err_no));
