@@ -62,20 +62,20 @@ int parse_opt(envid_t veid, int argc, char *argv[], struct option *opt,
 			ret == ERR_LONG_TRUNC)
 		{
 			if (option_index < 0) {
-				logger(0, 0, "Bad parameter for"
+				logger(-1, 0, "Bad parameter for"
 					" -%c : %s", c, optarg);
 				return VZ_INVALID_PARAMETER_VALUE;
 			} else {
-				logger(0, 0, "Bad parameter for"
+				logger(-1, 0, "Bad parameter for"
 					" --%s: %s",
 					opt[option_index].name, optarg);
 				return VZ_INVALID_PARAMETER_VALUE;
 			}
 		} else if (ret == ERR_UNK) {
 			if (option_index < 0)
-				logger(0, 0, "Invalid option -%c", c);
+				logger(-1, 0, "Invalid option -%c", c);
 			else
-				logger(0, 0, "Invalid option --%s",
+				logger(-1, 0, "Invalid option --%s",
 					opt[option_index].name);
 			return VZ_INVALID_PARAMETER_SYNTAX;
                 }
@@ -90,12 +90,13 @@ int parse_opt(envid_t veid, int argc, char *argv[], struct option *opt,
 	return 0;
 }
 
-static int parse_start_opt(int argc, char **argv, vps_opt *opt)
+static int parse_start_opt(int argc, char **argv, vps_param *param)
 {
 	int c, ret = 0;
 	struct option start_options[] = {
 	{"force", no_argument, NULL, PARAM_FORCE},
-	{"skip_ve_setup",no_argument, NULL, PARAM_SKIP_VE_SETUP},
+	{"skip_ve_setup", no_argument, NULL, PARAM_SKIP_VE_SETUP},
+	{"wait", no_argument, NULL, PARAM_WAIT},
 
 	{ NULL, 0, NULL, 0 }
 };
@@ -106,10 +107,13 @@ static int parse_start_opt(int argc, char **argv, vps_opt *opt)
 			break;
 		switch (c) {
 		case PARAM_FORCE:
-			opt->start_force = YES;
+			param->opt.start_force = YES;
 			break;
 		case PARAM_SKIP_VE_SETUP:
-			opt->skip_setup = YES;
+			param->opt.skip_setup = YES;
+			break;
+		case PARAM_WAIT:
+			param->res.misc.wait = YES;
 			break;
 		default:
 			ret = VZ_INVALID_PARAMETER_SYNTAX;
@@ -127,13 +131,14 @@ static int start(vps_handler *h, envid_t veid, vps_param *g_p,
 	if (g_p->opt.start_disabled == YES &&
 		cmd_p->opt.start_force != YES)
 	{
-		logger(0, 0, "VPS start disabled");
+		logger(-1, 0, "VE start disabled");
 		return VZ_VE_START_DISABLED;
 	}
 	if (vps_is_run(h, veid)) {
-		logger(0, 0, "VPS is already running");
+		logger(-1, 0, "VE is already running");
 		return VZ_VE_RUNNING;
 	}
+	g_p->res.misc.wait = cmd_p->res.misc.wait;
 	ret = vps_start(h, veid, g_p,
 		cmd_p->opt.skip_setup == YES ? SKIP_SETUP : 0, &g_action);
 	return ret;
@@ -222,7 +227,19 @@ static int create(vps_handler *h, envid_t veid, vps_param *vps_p,
 static int destroy(vps_handler *h, envid_t veid, vps_param *g_p,
 	vps_param *cmd_p)
 {
-	return vps_destroy(h, veid, &g_p->res.fs);
+	int ret, id;
+	char buf[STR_SIZE];
+	char *name = g_p->res.name.name;
+
+	ret = vps_destroy(h, veid, &g_p->res.fs);
+	if (!ret && name != NULL) {
+		id = get_veid_by_name(name);
+		if (id == veid) {
+			snprintf(buf, sizeof(buf), VENAME_DIR "/%s.conf", name);
+			unlink(buf);
+		}
+	}
+	return ret;
 }
 
 static int parse_chkpnt_opt(int argc, char **argv, vps_param *vps_p)
@@ -285,9 +302,9 @@ static int parse_chkpnt_opt(int argc, char **argv, vps_param *vps_p)
 			break;
 		default:
 			if (option_index < 0)
-				logger(0, 0, "Invalid option -%c", c);
+				logger(-1, 0, "Invalid option -%c", c);
 			else
-				logger(0, 0, "Invalid option --%s", 
+				logger(-1, 0, "Invalid option --%s", 
 					chkpnt_options[option_index].name);
 			return VZ_INVALID_PARAMETER_SYNTAX;
 		}
@@ -298,7 +315,7 @@ static int parse_chkpnt_opt(int argc, char **argv, vps_param *vps_p)
 	return 0;
 
 err_syntax:
-	logger(0, 0, "Invalid syntax: only one sub command may be used");
+	logger(-1, 0, "Invalid syntax: only one sub command may be used");
 	return VZ_INVALID_PARAMETER_SYNTAX;
 }
 
@@ -355,9 +372,9 @@ static int parse_restore_opt(int argc, char **argv, vps_param *vps_p)
 			break;
 		default:
 			if (option_index < 0)
-				logger(0, 0, "Invalid option -%c", c);
+				logger(-1, 0, "Invalid option -%c", c);
 			else
-				logger(0, 0, "Invalid option --%s", 
+				logger(-1, 0, "Invalid option --%s", 
 					restore_options[option_index].name);
 			return VZ_INVALID_PARAMETER_SYNTAX;
 		}
@@ -367,7 +384,7 @@ static int parse_restore_opt(int argc, char **argv, vps_param *vps_p)
 		cpt->cmd = CMD_RESTORE;
 	return 0;
 err_syntax:
-	logger(0, 0, "Invalid syntax: only one sub command may be used");
+	logger(-1, 0, "Invalid syntax: only one sub command may be used");
 	return VZ_INVALID_PARAMETER_SYNTAX;
 }
 int check_set_mode(vps_handler *h, envid_t veid, int setmode, int apply,
@@ -377,7 +394,7 @@ int check_set_mode(vps_handler *h, envid_t veid, int setmode, int apply,
 
 	/* Check parameters that can't be set on running VE */
 	if (new_res->cap.on || new_res->cap.off) {
-		logger(0, 0, "Unable to set capability on running VPS");
+		logger(-1, 0, "Unable to set capability on running VE");
 		if (setmode == SET_RESTART)
 			goto restart_ve;
 		else if (setmode != SET_IGNORE)
@@ -387,7 +404,7 @@ int check_set_mode(vps_handler *h, envid_t veid, int setmode, int apply,
 		if (!old_res->env.ipt_mask ||
 			new_res->env.ipt_mask != old_res->env.ipt_mask)
 		{
-			logger(0, 0, "Unable to set iptables on running VPS");
+			logger(-1, 0, "Unable to set iptables on running VE");
 			if (setmode == SET_RESTART)
 				goto restart_ve;
 			else if (setmode != SET_IGNORE)
@@ -395,8 +412,8 @@ int check_set_mode(vps_handler *h, envid_t veid, int setmode, int apply,
 		}
 	}
 	if (err && setmode == SET_NONE) {
-		logger(0, 0, "WARNING: Some of the parameters"
-			" could not be applied to a running VPS.\n"
+		logger(-1, 0, "WARNING: Some of the parameters"
+			" could not be applied to a running VE.\n"
 			"\tPlease consider using --setmode option");
 	}
 	return err;
@@ -430,7 +447,7 @@ static int apply_param_from_cfg(int veid, vps_param *param, char *cfg)
 		return 0;
 	snprintf(conf, sizeof(conf), VPS_CONF_DIR "ve-%s.conf-sample", cfg);
 	if (!stat_file(conf)) {
-		logger(0, 0, "Sample config file does not found: %s", conf);
+		logger(-1, 0, "Sample config file does not found: %s", conf);
                 return VZ_APPLY_CONFIG_ERROR;
 	}
 	new = init_vps_param();
@@ -490,7 +507,11 @@ static int set(vps_handler *h, envid_t veid, vps_param *g_p, vps_param *vps_p,
 	ret = 0;
 
 	cmd_p->g_param = g_p;
-
+	if (cmd_p->opt.apply_cfg_map == APPCONF_MAP_NAME) {
+		ret = set_name(veid, g_p->res.name.name, g_p->res.name.name);
+		if (ret != 0)
+			return ret;
+	}
 	/* Reset UB parameters from config  */
 	if (cmd_p->opt.reset_ub == YES) {
 		ret = vps_set_ublimit(h, veid, &vps_p->res.ub);
@@ -498,13 +519,13 @@ static int set(vps_handler *h, envid_t veid, vps_param *g_p, vps_param *vps_p,
 		return ret;
 	}
 	if (cmd_p->opt.setmode == SET_RESTART && !cmd_p->opt.save) {
-		logger(0, 0, "it's impossible to use"
+		logger(-1, 0, "it's impossible to use"
 			" restart mode without --save");
 		return VZ_INVALID_PARAMETER_SYNTAX;
 	}
 	if (cmd_p->res.name.name != NULL) {
 		if (!cmd_p->opt.save) {
-			logger(0, 0, "Error: unable to use"
+			logger(-1, 0, "Error: unable to use"
 				 " --name option without --save");
 			ret =  VZ_SET_NAME_ERROR;
 		} else {
@@ -521,13 +542,13 @@ static int set(vps_handler *h, envid_t veid, vps_param *g_p, vps_param *vps_p,
 		if (cmd_p->res.fs.private_orig != NULL) {
 			free(cmd_p->res.fs.private_orig);
 			cmd_p->res.fs.private_orig = NULL;
-			logger(0, 0,"Unable to change VE_PRIVATE on runing VPS");
+			logger(-1, 0,"Unable to change VE_PRIVATE on runing VE");
 			return VZ_VE_RUNNING;
 		}
 		if (cmd_p->res.fs.root_orig != NULL) {
 			free(cmd_p->res.fs.root_orig);
 			cmd_p->res.fs.root_orig = NULL;
-			logger(0, 0, "Unable to change VE_ROOT on runing VPS");
+			logger(-1, 0, "Unable to change VE_ROOT on runing VE");
 			return VZ_VE_RUNNING;
 		}
 	}
@@ -565,7 +586,7 @@ static int set(vps_handler *h, envid_t veid, vps_param *g_p, vps_param *vps_p,
 			goto err;
 		}
 	}
-	/* Skip apply parameters on stopped VPS */
+	/* Skip applying parameters on stopped VE */
 	if (cmd_p->opt.save && !is_run) {
 		ret = mod_setup(h, veid, STATE_STOPPED, SKIP_NONE, &g_action,
 			cmd_p);
@@ -615,11 +636,10 @@ static int enter(vps_handler *h, envid_t veid, vps_param *g_p,
 	if (check_var(root, "VE_ROOT is not set"))
 		return VZ_VE_ROOT_NOTSET;
 	if (!vps_is_run(h, veid)) {
-		logger(0, 0, "VPS is not running");
+		logger(-1, 0, "VE is not running");
 		return VZ_VE_NOT_RUNNING;
 	}
-	do_enter(h, veid, root);
-	return 0;
+	return do_enter(h, veid, root);
 }
 
 static int exec(vps_handler *h, int action, envid_t veid, char *root, int argc,
@@ -693,7 +713,7 @@ static int show_status(vps_handler *h, envid_t veid, vps_param *param)
 		exist = 1;
 	mounted = vps_is_mounted(fs->root);
 	run = vps_is_run(h, veid);
-	printf("VPSID %d %s %s %s\n", veid,
+	printf("VEID %d %s %s %s\n", veid,
 		exist ? "exist" : "deleted",
 		mounted ? "mounted" : "unmounted",
 		run ? "running" : "down");
@@ -731,7 +751,7 @@ int parse_action_opt(envid_t veid, int action, int argc, char *argv[],
 		ret = parse_stop_opt(argc, argv, &param->opt);
 		break;
 	case ACTION_START:
-		ret = parse_start_opt(argc, argv, &param->opt);
+		ret = parse_start_opt(argc, argv, param);
 		break;
 	case ACTION_DESTROY:
 		break;
@@ -791,11 +811,11 @@ int run_action(envid_t veid, int action, vps_param *g_p, vps_param *vps_p,
 		if (skiplock != YES) {
 			lock_id = vps_lock(veid, g_p->opt.lockdir, "");
 			if (lock_id > 0) {
-				logger(0, 0, "VPS already locked");
+				logger(-1, 0, "VE already locked");
 				ret = VZ_LOCKED;
 				goto err;
 			} else if (lock_id < 0) {
-				logger(0, 0, "Unable to lock VPS");
+				logger(-1, 0, "Unable to lock VE");
 				ret = VZ_SYSTEM_ERROR;
 				goto err;
 			}
@@ -835,7 +855,7 @@ int run_action(envid_t veid, int action, vps_param *g_p, vps_param *vps_p,
 		if (cmd_p->opt.save == YES) {
 			get_vps_conf_path(veid, fname, sizeof(fname));
 			vps_save_config(veid, fname, cmd_p, vps_p, &g_action);
-			logger(0, 0, "Saved parameters for VPS %d", veid);
+			logger(0, 0, "Saved parameters for VE %d", veid);
 		} else if (cmd_p->opt.save != NO) {
 			if (list_empty(&cmd_p->res.misc.userpw)) {
 				logger(0, 0, "WARNING: Settings were not saved"
@@ -880,7 +900,7 @@ int run_action(envid_t veid, int action, vps_param *g_p, vps_param *vps_p,
 		break;
 	}
 err:
-	/* Unlock VPS in case lock taken */
+	/* Unlock VE in case lock taken */
 	if (skiplock != YES && !lock_id)
 		vps_unlock(veid, g_p->opt.lockdir);
 	vz_close(h);
